# vivetool

Enable or disable hidden Windows feature flags by numeric ID using ViVeTool. Uses bundled ViVeTool.exe from C:/USB/system/vivetool/.

## Structure

- `schema.json`: Interface
- `tool.py`: CLI
- worker.py: Background
